@@ -6,8 +6,8 @@ import Radio from '@material-ui/core/Radio';
 import RadioGroup from '@material-ui/core/RadioGroup';
 import FormControlLabel from '@material-ui/core/FormControlLabel';
 import Slider from '@material-ui/core/Slider';
-// import Button from '@material-ui/core/Button';
-// import Switch from '@material-ui/core/Switch';
+import UploadButtons from './uploadbuttons';
+import Switch from '@material-ui/core/Switch';
 
 export interface IProps {
   data: string;
@@ -16,6 +16,7 @@ export interface IProps {
 export interface IState {
   filter?: string;
   value: string;
+  spin: boolean;
 }
 
 const marks1 = [
@@ -78,7 +79,7 @@ export class Visualizer extends React.Component<IProps, IState> {
 
     this.dark = true;
     this.uuid = _.uniqueId('ngl_');
-    this.state = { value: 'black' };
+    this.state = { value: 'black', spin: false };
 
     window.requestAnimationFrame(() => {
       NGL.DatasourceRegistry.add(
@@ -166,6 +167,20 @@ export class Visualizer extends React.Component<IProps, IState> {
       .setParameters({ isolevel: val[0] });
   };
 
+  loadStructure = (event: React.ChangeEvent<HTMLInputElement>): void => {
+    this._stage.loadFile(event.target.files[0]).then((o: any) => {
+      o.addRepresentation('ball+stick', {
+        name: 'structure',
+        visible: true,
+      });
+    });
+  };
+
+  toggleSpin = (event: React.ChangeEvent<HTMLInputElement>): void => {
+    this.setState({ spin: event.target.checked });
+    this._stage.toggleSpin();
+  };
+
   render(): JSX.Element {
     return (
       <div className="container">
@@ -215,7 +230,13 @@ export class Visualizer extends React.Component<IProps, IState> {
             />
           </Grid>
         </Grid>
-        <Grid container direction="row" justify="center" alignItems="center">
+        <Grid
+          container
+          direction="row"
+          justify="center"
+          alignItems="center"
+          style={{ marginTop: '20px' }}
+        >
           <RadioGroup
             aria-label="backgroundcolor"
             name="backgroundcolor1"
@@ -232,6 +253,13 @@ export class Visualizer extends React.Component<IProps, IState> {
               label="Yellow"
             />
           </RadioGroup>
+          <UploadButtons onChange={this.loadStructure} />
+          <Switch
+            checked={this.state.spin}
+            onChange={this.toggleSpin}
+            name="spin"
+            color="secondary"
+          />
         </Grid>
       </div>
     );
